Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func New ¶
func New(fn ...OptionFn) http.RoundTripper
New returns a RoundTripper that dumps the request/response pair to disk to the "where" directory It needs to be used as a base transport if used to debug the headers produced by the OAuth2 or HTTP-Signatures authorization transports.
Types ¶
type OptionFn ¶
func WithTransport ¶
func WithTransport(tr http.RoundTripper) OptionFn
Click to show internal directories.
Click to hide internal directories.